@@ -1,5 +1,5 @@
 @MappableLib(generateInitializerForScope: InitializerScope.library)
-library main;
+library;
 
 import 'package:dart_mappable/dart_mappable.dart';
 import 'package:test/test.dart';
